==> ejc-probid-api-3.0.0-20220714.030602-2-sources.jar: com/ejianc/business/bid/vo/ProjectVO.java <==
package com.ejianc.business.bid.vo;

import java.util.Date;
import java.math.*;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;
import com.ejianc.framework.skeleton.template.BaseVO;


/**
 * 投标立项
 * 
 * @author generator
 * 
 */
public class ProjectVO extends BaseVO {
    private static final long serialVersionUID = 1L;
    
    private Long businessId; // 商机id
    private String projectName; // 招标项目名称（带入）
    private String constructionUnit; // 建设单位
    private Long unitnatureId; // 建设单位 性质
    private String unitnatureName; // 建设单位 性质(name)
    private String unitnatureCode; // 建设单位 性质(name)
    private String biddingAgency; // 招标代理机构
    private Date registrationDeadline; // 报名截止日期
    private Date bidOpenDate; // 开标日期
    private String tenderMode; // 招标方式
    private String tenderModeName; // 招标方式名称
    private String reviewMode; // 评审方式
    private String reviewModeName; // 评审方式名称
    private String projectInitType; // 立项类别
    private String projectInitTypeName; // 立项类别 名称
    private String detailedAddress; // 详细地址
    private String area; // 区域
    private BigDecimal projectTotalMny; // 项目总投资
    private BigDecimal projectTotalArea; // 项目总面积
    private Long projectManagerId; // 项目经理
    private String projectManagerName; // 项目经理 名称
    private Integer projectDuration; // 工程工期
    private Long projectTypeId; // 项目类型
    private String projectTypeName; // 项目类型名称
    private Long bidUnitId; // 投标单位
    private String bidUnitName; // 投标单位 名称
    private String bidUnitCode; // 投标单位 编码
    private Long applyUserId; // 投标申请人
    private String applyUserName; // 投标申请人 名称
    private String applyUserCode; // 投标申请人 编码
    private String applyUserPhone; // 申请人联系方式
    private String entrustInformationId; // 申请人委托资料
    private String entrustInformationName; // 申请人委托资料
    private String bidStage; // 投标阶段
    private String bidStatus; // 投标状态  0投标中、1中标、2未中标、3已中止、4预审不通过。
    private String billCode; // 单据编码
    private Integer billState; // 单据状态 ：0自由态，1已提交，2审批中，3审批通过，4驳回，5提交后有人审批中
    private Date commitData; // 提交日期
    private Date commitDate; // 提交日期
    private Date effectiveDate; // 生效日期
    private String commitUserCode; // 提交人账号
    private String commitUserName; // 提交人名字
    private String memo; // 备注
    

    public Long getBusinessId() {
        return businessId;
    }

    public void setBusinessId(Long businessId) {
        this.businessId = businessId;
    }
    public String getProjectName() {
        return projectName;
    }

    public void setProjectName(String projectName) {
        this.projectName = projectName;
    }
    public String getConstructionUnit() {
        return constructionUnit;
    }

    public void setConstructionUnit(String constructionUnit) {
        this.constructionUnit = constructionUnit;
    }
    public Long getUnitnatureId() {
        return unitnatureId;
    }

    public void setUnitnatureId(Long unitnatureId) {
        this.unitnatureId = unitnatureId;
    }
    public String getUnitnatureName() {
        return unitnatureName;
    }

    public void setUnitnatureName(String unitnatureName) {
        this.unitnatureName = unitnatureName;
    }
    public String getUnitnatureCode() {
        return unitnatureCode;
    }

    public void setUnitnatureCode(String unitnatureCode) {
        this.unitnatureCode = unitnatureCode;
    }
    public String getBiddingAgency() {
        return biddingAgency;
    }

    public void setBiddingAgency(String biddingAgency) {
        this.biddingAgency = biddingAgency;
    }
    public Date getRegistrationDeadline() {
        return registrationDeadline;
    }

    public void setRegistrationDeadline(Date registrationDeadline) {
        this.registrationDeadline = registrationDeadline;
    }
    public Date getBidOpenDate() {
        return bidOpenDate;
    }

    public void setBidOpenDate(Date bidOpenDate) {
        this.bidOpenDate = bidOpenDate;
    }
    public String getTenderMode() {
        return tenderMode;
    }

    public void setTenderMode(String tenderMode) {
        this.tenderMode = tenderMode;
    }
    public String getTenderModeName() {
        return tenderModeName;
    }

    public void setTenderModeName(String tenderModeName) {
        this.tenderModeName = tenderModeName;
    }
    public String getReviewMode() {
        return reviewMode;
    }

    public void setReviewMode(String reviewMode) {
        this.reviewMode = reviewMode;
    }
    public String getReviewModeName() {
        return reviewModeName;
    }

    public void setReviewModeName(String reviewModeName) {
        this.reviewModeName = reviewModeName;
    }
    public String getProjectInitType() {
        return projectInitType;
    }

    public void setProjectInitType(String projectInitType) {
        this.projectInitType = projectInitType;
    }
    public String getProjectInitTypeName() {
        return projectInitTypeName;
    }

    public void setProjectInitTypeName(String projectInitTypeName) {
        this.projectInitTypeName = projectInitTypeName;
    }
    public String getDetailedAddress() {
        return detailedAddress;
    }

    public void setDetailedAddress(String detailedAddress) {
        this.detailedAddress = detailedAddress;
    }
    public String getArea() {
        return area;
    }

    public void setArea(String area) {
        this.area = area;
    }
    public BigDecimal getProjectTotalMny() {
        return projectTotalMny;
    }

    public void setProjectTotalMny(BigDecimal projectTotalMny) {
        this.projectTotalMny = projectTotalMny;
    }
    public BigDecimal getProjectTotalArea() {
        return projectTotalArea;
    }

    public void setProjectTotalArea(BigDecimal projectTotalArea) {
        this.projectTotalArea = projectTotalArea;
    }
    public Long getProjectManagerId() {
        return projectManagerId;
    }

    public void setProjectManagerId(Long projectManagerId) {
        this.projectManagerId = projectManagerId;
    }
    public String getProjectManagerName() {
        return projectManagerName;
    }

    public void setProjectManagerName(String projectManagerName) {
        this.projectManagerName = projectManagerName;
    }
    public Integer getProjectDuration() {
        return projectDuration;
    }

    public void setProjectDuration(Integer projectDuration) {
        this.projectDuration = projectDuration;
    }
    public Long getProjectTypeId() {
        return projectTypeId;
    }

    public void setProjectTypeId(Long projectTypeId) {
        this.projectTypeId = projectTypeId;
    }
    public String getProjectTypeName() {
        return projectTypeName;
    }

    public void setProjectTypeName(String projectTypeName) {
        this.projectTypeName = projectTypeName;
    }
    public Long getBidUnitId() {
        return bidUnitId;
    }

    public void setBidUnitId(Long bidUnitId) {
        this.bidUnitId = bidUnitId;
    }
    public String getBidUnitName() {
        return bidUnitName;
    }

    public void setBidUnitName(String bidUnitName) {
        this.bidUnitName = bidUnitName;
    }
    public String getBidUnitCode() {
        return bidUnitCode;
    }

    public void setBidUnitCode(String bidUnitCode) {
        this.bidUnitCode = bidUnitCode;
    }
    public Long getApplyUserId() {
        return applyUserId;
    }

    public void setApplyUserId(Long applyUserId) {
        this.applyUserId = applyUserId;
    }
    public String getApplyUserName() {
        return applyUserName;
    }

    public void setApplyUserName(String applyUserName) {
        this.applyUserName = applyUserName;
    }
    public String getApplyUserCode() {
        return applyUserCode;
    }

    public void setApplyUserCode(String applyUserCode) {
        this.applyUserCode = applyUserCode;
    }
    public String getApplyUserPhone() {
        return applyUserPhone;
    }

    public void setApplyUserPhone(String applyUserPhone) {
        this.applyUserPhone = applyUserPhone;
    }
    public String getEntrustInformationId() {
        return entrustInformationId;
    }

    public void setEntrustInformationId(String entrustInformationId) {
        this.entrustInformationId = entrustInformationId;
    }
    public String getEntrustInformationName() {
        return entrustInformationName;
    }

    public void setEntrustInformationName(String entrustInformationName) {
        this.entrustInformationName = entrustInformationName;
    }
    public String getBidStage() {
        return bidStage;
    }

    public void setBidStage(String bidStage) {
        this.bidStage = bidStage;
    }
    public String getBidStatus() {
        return bidStatus;
    }

    public void setBidStatus(String bidStatus) {
        this.bidStatus = bidStatus;
    }
    public String getBillCode() {
        return billCode;
    }

    public void setBillCode(String billCode) {
        this.billCode = billCode;
    }
    public Integer getBillState() {
        return billState;
    }

    public void setBillState(Integer billState) {
        this.billState = billState;
    }
    public Date getCommitData() {
        return commitData;
    }

    public void setCommitData(Date commitData) {
        this.commitData = commitData;
    }
    public Date getCommitDate() {
        return commitDate;
    }

    public void setCommitDate(Date commitDate) {
        this.commitDate = commitDate;
    }
    public Date getEffectiveDate() {
        return effectiveDate;
    }

    public void setEffectiveDate(Date effectiveDate) {
        this.effectiveDate = effectiveDate;
    }
    public String getCommitUserCode() {
        return commitUserCode;
    }

    public void setCommitUserCode(String commitUserCode) {
        this.commitUserCode = commitUserCode;
    }
    public String getCommitUserName() {
        return commitUserName;
    }

    public void setCommitUserName(String commitUserName) {
        this.commitUserName = commitUserName;
    }
    public String getMemo() {
        return memo;
    }

    public void setMemo(String memo) {
        this.memo = memo;
    }
    
}

==> ejc-probid-api-3.0.0-20220714.034156-3-sources.jar: com/ejianc/business/bid/vo/ProjectVO.java <==
package com.ejianc.business.bid.vo;

import java.util.Date;
import java.math.*;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;

import com.baomidou.mybatisplus.annotation.TableField;
import com.ejianc.framework.skeleton.template.BaseVO;


/**
 * 投标立项
 * 
 * @author generator
 * 
 */
public class ProjectVO extends BaseVO {
    private static final long serialVersionUID = 1L;
    
    private Long businessId; // 商机id
    private String projectName; // 招标项目名称（带入）
    private String constructionUnit; // 建设单位
    private Long unitnatureId; // 建设单位 性质
    private String unitnatureName; // 建设单位 性质(name)
    private String unitnatureCode; // 建设单位 性质(name)
    private String biddingAgency; // 招标代理机构
    private Date registrationDeadline; // 报名截止日期
    private Date bidOpenDate; // 开标日期
    private String tenderModeCode; // 招标方式编码
    private Long tenderModeId; // 招标方式
    private String tenderModeName; // 招标方式名称
    private String reviewMode; // 评审方式
    private String reviewModeName; // 评审方式名称
    private String projectInitType; // 立项类别
    private String projectInitTypeName; // 立项类别 名称
    private String detailedAddress; // 详细地址
    private String area; // 区域
    private BigDecimal projectTotalMny; // 项目总投资
    private BigDecimal projectTotalArea; // 项目总面积
    private Long projectManagerId; // 项目经理
    private String projectManagerName; // 项目经理 名称
    private Integer projectDuration; // 工程工期
    private Long projectTypeId; // 项目类型
    private String projectTypeName; // 项目类型名称
    private Long bidUnitId; // 投标单位
    private String bidUnitName; // 投标单位 名称
    private String bidUnitCode; // 投标单位 编码
    private Long applyUserId; // 投标申请人
    private String applyUserName; // 投标申请人 名称
    private String applyUserCode; // 投标申请人 编码
    private String applyUserPhone; // 申请人联系方式
    private String entrustInformationId; // 申请人委托资料
    private String entrustInformationName; // 申请人委托资料
    private String bidStage; // 投标阶段
    private String bidStatus; // 投标状态  0投标中、1中标、2未中标、3已中止、4预审不通过。
    private String billCode; // 单据编码
    private Integer billState; // 单据状态 ：0自由态，1已提交，2审批中，3审批通过，4驳回，5提交后有人审批中
    private Date commitData; // 提交日期
    private Date commitDate; // 提交日期
    private Date effectiveDate; // 生效日期
    private String commitUserCode; // 提交人账号
    private String commitUserName; // 提交人名字
    private String memo; // 备注
    

    public Long getBusinessId() {
        return businessId;
    }

    public void setBusinessId(Long businessId) {
        this.businessId = businessId;
    }
    public String getProjectName() {
        return projectName;
    }

    public void setProjectName(String projectName) {
        this.projectName = projectName;
    }
    public String getConstructionUnit() {
        return constructionUnit;
    }

    public void setConstructionUnit(String constructionUnit) {
        this.constructionUnit = constructionUnit;
    }
    public Long getUnitnatureId() {
        return unitnatureId;
    }

    public void setUnitnatureId(Long unitnatureId) {
        this.unitnatureId = unitnatureId;
    }
    public String getUnitnatureName() {
        return unitnatureName;
    }

    public void setUnitnatureName(String unitnatureName) {
        this.unitnatureName = unitnatureName;
    }
    public String getUnitnatureCode() {
        return unitnatureCode;
    }

    public void setUnitnatureCode(String unitnatureCode) {
        this.unitnatureCode = unitnatureCode;
    }
    public String getBiddingAgency() {
        return biddingAgency;
    }

    public void setBiddingAgency(String biddingAgency) {
        this.biddingAgency = biddingAgency;
    }
    public Date getRegistrationDeadline() {
        return registrationDeadline;
    }

    public void setRegistrationDeadline(Date registrationDeadline) {
        this.registrationDeadline = registrationDeadline;
    }
    public Date getBidOpenDate() {
        return bidOpenDate;
    }

    public void setBidOpenDate(Date bidOpenDate) {
        this.bidOpenDate = bidOpenDate;
    }

    public String getTenderModeCode() {
        return tenderModeCode;
    }

    public void setTenderModeCode(String tenderModeCode) {
        this.tenderModeCode = tenderModeCode;
    }

    public Long getTenderModeId() {
        return tenderModeId;
    }

    public void setTenderModeId(Long tenderModeId) {
        this.tenderModeId = tenderModeId;
    }

    public String getTenderModeName() {
        return tenderModeName;
    }

    public void setTenderModeName(String tenderModeName) {
        this.tenderModeName = tenderModeName;
    }
    public String getReviewMode() {
        return reviewMode;
    }

    public void setReviewMode(String reviewMode) {
        this.reviewMode = reviewMode;
    }
    public String getReviewModeName() {
        return reviewModeName;
    }

    public void setReviewModeName(String reviewModeName) {
        this.reviewModeName = reviewModeName;
    }
    public String getProjectInitType() {
        return projectInitType;
    }

    public void setProjectInitType(String projectInitType) {
        this.projectInitType = projectInitType;
    }
    public String getProjectInitTypeName() {
        return projectInitTypeName;
    }

    public void setProjectInitTypeName(String projectInitTypeName) {
        this.projectInitTypeName = projectInitTypeName;
    }
    public String getDetailedAddress() {
        return detailedAddress;
    }

    public void setDetailedAddress(String detailedAddress) {
        this.detailedAddress = detailedAddress;
    }
    public String getArea() {
        return area;
    }

    public void setArea(String area) {
        this.area = area;
    }
    public BigDecimal getProjectTotalMny() {
        return projectTotalMny;
    }

    public void setProjectTotalMny(BigDecimal projectTotalMny) {
        this.projectTotalMny = projectTotalMny;
    }
    public BigDecimal getProjectTotalArea() {
        return projectTotalArea;
    }

    public void setProjectTotalArea(BigDecimal projectTotalArea) {
        this.projectTotalArea = projectTotalArea;
    }
    public Long getProjectManagerId() {
        return projectManagerId;
    }

    public void setProjectManagerId(Long projectManagerId) {
        this.projectManagerId = projectManagerId;
    }
    public String getProjectManagerName() {
        return projectManagerName;
    }

    public void setProjectManagerName(String projectManagerName) {
        this.projectManagerName = projectManagerName;
    }
    public Integer getProjectDuration() {
        return projectDuration;
    }

    public void setProjectDuration(Integer projectDuration) {
        this.projectDuration = projectDuration;
    }
    public Long getProjectTypeId() {
        return projectTypeId;
    }

    public void setProjectTypeId(Long projectTypeId) {
        this.projectTypeId = projectTypeId;
    }
    public String getProjectTypeName() {
        return projectTypeName;
    }

    public void setProjectTypeName(String projectTypeName) {
        this.projectTypeName = projectTypeName;
    }
    public Long getBidUnitId() {
        return bidUnitId;
    }

    public void setBidUnitId(Long bidUnitId) {
        this.bidUnitId = bidUnitId;
    }
    public String getBidUnitName() {
        return bidUnitName;
    }

    public void setBidUnitName(String bidUnitName) {
        this.bidUnitName = bidUnitName;
    }
    public String getBidUnitCode() {
        return bidUnitCode;
    }

    public void setBidUnitCode(String bidUnitCode) {
        this.bidUnitCode = bidUnitCode;
    }
    public Long getApplyUserId() {
        return applyUserId;
    }

    public void setApplyUserId(Long applyUserId) {
        this.applyUserId = applyUserId;
    }
    public String getApplyUserName() {
        return applyUserName;
    }

    public void setApplyUserName(String applyUserName) {
        this.applyUserName = applyUserName;
    }
    public String getApplyUserCode() {
        return applyUserCode;
    }

    public void setApplyUserCode(String applyUserCode) {
        this.applyUserCode = applyUserCode;
    }
    public String getApplyUserPhone() {
        return applyUserPhone;
    }

    public void setApplyUserPhone(String applyUserPhone) {
        this.applyUserPhone = applyUserPhone;
    }
    public String getEntrustInformationId() {
        return entrustInformationId;
    }

    public void setEntrustInformationId(String entrustInformationId) {
        this.entrustInformationId = entrustInformationId;
    }
    public String getEntrustInformationName() {
        return entrustInformationName;
    }

    public void setEntrustInformationName(String entrustInformationName) {
        this.entrustInformationName = entrustInformationName;
    }
    public String getBidStage() {
        return bidStage;
    }

    public void setBidStage(String bidStage) {
        this.bidStage = bidStage;
    }
    public String getBidStatus() {
        return bidStatus;
    }

    public void setBidStatus(String bidStatus) {
        this.bidStatus = bidStatus;
    }
    public String getBillCode() {
        return billCode;
    }

    public void setBillCode(String billCode) {
        this.billCode = billCode;
    }
    public Integer getBillState() {
        return billState;
    }

    public void setBillState(Integer billState) {
        this.billState = billState;
    }
    public Date getCommitData() {
        return commitData;
    }

    public void setCommitData(Date commitData) {
        this.commitData = commitData;
    }
    public Date getCommitDate() {
        return commitDate;
    }

    public void setCommitDate(Date commitDate) {
        this.commitDate = commitDate;
    }
    public Date getEffectiveDate() {
        return effectiveDate;
    }

    public void setEffectiveDate(Date effectiveDate) {
        this.effectiveDate = effectiveDate;
    }
    public String getCommitUserCode() {
        return commitUserCode;
    }

    public void setCommitUserCode(String commitUserCode) {
        this.commitUserCode = commitUserCode;
    }
    public String getCommitUserName() {
        return commitUserName;
    }

    public void setCommitUserName(String commitUserName) {
        this.commitUserName = commitUserName;
    }
    public String getMemo() {
        return memo;
    }

    public void setMemo(String memo) {
        this.memo = memo;
    }
    
}
